[Yanel-commits] rev 42253 - public/yanel/trunk/src/core/java/org/wyona/yanel/core/map

michi at wyona.com michi at wyona.com
Sun Apr 5 08:36:30 CEST 2009


Author: michi
Date: 2009-04-05 08:36:30 +0200 (Sun, 05 Apr 2009)
New Revision: 42253

Modified:
   public/yanel/trunk/src/core/java/org/wyona/yanel/core/map/RealmManager.java
Log:
difference between configuration files clarified

Modified: public/yanel/trunk/src/core/java/org/wyona/yanel/core/map/RealmManager.java
===================================================================
--- public/yanel/trunk/src/core/java/org/wyona/yanel/core/map/RealmManager.java	2009-04-05 06:14:37 UTC (rev 42252)
+++ public/yanel/trunk/src/core/java/org/wyona/yanel/core/map/RealmManager.java	2009-04-05 06:36:30 UTC (rev 42253)
@@ -47,7 +47,7 @@
 
     private static Logger log = Logger.getLogger(RealmManager.class);
 
-    public static String CONFIGURATION_FILE = Yanel.DEFAULT_CONFIGURATION_FILE;
+    private static String CONFIGURATION_FILE = Yanel.DEFAULT_CONFIGURATION_FILE;
 
     public static String REALM_DEFAULT_CONFIG_NAME = "realm.xml";
 
@@ -68,20 +68,22 @@
 
     /**
      * Initializes realms
      * @param configurationFile Something like yanel.xml or yanel.properties
      */
-    public RealmManager(String configurationFile) throws ConfigurationException {
-        File realmsConfigFile = getSetRealmsConfigFile(configurationFile);
+    public RealmManager(String yanelConfigurationFile) throws ConfigurationException {
+        log.debug("Yanel Configuration: " + yanelConfigurationFile);
+        File realmsConfigFile = getSetRealmsConfigFile(yanelConfigurationFile);
         log.debug("Realms Configuration: " + realmsConfigFile);
         readRealms(realmsConfigFile);
     }
 
     /**
      * Get realms configuration file
      * @param configurationFile Something like yanel.xml or yanel.properties
      */
-    public File getSetRealmsConfigFile(String configurationFile) throws ConfigurationException {
-        CONFIGURATION_FILE = configurationFile;
+    public File getSetRealmsConfigFile(String yanelConfigurationFile) throws ConfigurationException {
+        CONFIGURATION_FILE = yanelConfigurationFile;
 
         if (RealmManager.class.getClassLoader().getResource(CONFIGURATION_FILE) == null) {
             CONFIGURATION_FILE = Yanel.DEFAULT_CONFIGURATION_FILE;
@@ -153,7 +155,7 @@
     }
 
     /**
-     *
+     * Get yanel configuration file
      */
     public String getConfigurationFile() {
         return CONFIGURATION_FILE;
@@ -187,8 +189,10 @@
         }
         
         try {
+            log.debug("Get default repo factory ...");
             RepositoryFactory defaultRepoFactory = yanel.getRepositoryFactory(Realm.DEFAULT_REPOSITORY_FACTORY_BEAN_ID);
             defaultRepoFactory.reset();
+            log.debug("Get default repo factory DONE.");
 
             RepositoryFactory rtiRepoFactory = yanel.getRepositoryFactory("RTIRepositoryFactory");
             rtiRepoFactory.reset();
@@ -68,20 +68,22 @@
     /**
      * Initializes realms
-     * @param configurationFile Something like yanel.xml or yanel.properties
+     * @param yanelConfigurationFile Yanel configuration, something like yanel.xml or yanel.properties
      */
@@ -68,20 +68,22 @@
     /**
      * Get realms configuration file
-     * @param configurationFile Something like yanel.xml or yanel.properties
+     * @param yanelConfigurationFile Yanel configuration, something like yanel.xml or yanel.properties
+     * @return Something like realms.xml
      */



More information about the Yanel-commits mailing list